@@ -35,7 +35,7 @@ class X_API:
 
     def get_dataset(
             self,
-            name: str
+            name: str,
     ) -> Dict[str, Any]:
         if not name:
             raise InvalidParamsError(param_name="dataset", param_value=name)
@@ -49,11 +49,27 @@ class X_API:
 
         return info
 
+    def get_dataset_name(
+            self,
+            name: str,
+    ) -> Dict[str, Any]:
+        if not name:
+            raise InvalidParamsError(param_name="dataset", param_value=name)
+
+        response = self.list_dataset_name(name=name, accurate=True)
+
+        try:
+            info = response["data"][0]
+        except IndexError as error:
+            raise ResourceNotExistError(resource="dataset", identification=name) from error
+
+        return info
+
     def list_datasets(
             self,
             name: Optional[str] = None,
             offset: int = 0,
-            limit: int = 128,
+            limit: int = 128
     ) -> Dict[str, Any]:
         post_data: Dict[str, Any] = {
             "offset": offset,
@@ -65,6 +81,26 @@ class X_API:
         response = self._client.open_api_do("POST", "search/dataset", json=post_data)
         return response.json()
 
+    def list_dataset_name(
+            self,
+            name: Optional[str] = None,
+            accurate: Optional[bool] = False,
+            offset: int = 0,
+            limit: int = 128
+    ) -> Dict[str, Any]:
+        post_data: Dict[str, Any] = {
+            "offset": offset,
+            "limit": limit,
+        }
+        if name:
+            post_data["name"] = name
+
+        if accurate:
+            post_data["accurate"] = True
+
+        response = self._client.open_api_do("POST", "search/dataset/name", json=post_data)
+        return response.json()
+
     def get_space(self, name: str) -> Dict[str, Any]:
         if not name:
             raise InvalidParamsError(param_name="space", param_value=name)
