@@ -2,7 +2,7 @@ import json
 import logging
 import os.path
 import time
-from typing import List, Dict, Optional, Any, TYPE_CHECKING, Set
+from typing import List, Dict, Optional, Any, TYPE_CHECKING
 
 from s3transfer.constants import GB
 from tqdm import tqdm
@@ -256,7 +256,7 @@ class Dataset(DatasetMeta):
                 upload_id = self._upload_files(file_path, storage_type, self._id)
             task_type = "cos"
 
-        elif os.path.isdir(file_path) and os.path.getsize(file_path) > 1 * GB:
+        elif os.path.isfile(file_path) and os.path.getsize(file_path) > 1 * GB:
             upload_id = self._upload_file(file_path, storage_type)
             task_type = "object_storage"
 
@@ -308,6 +308,7 @@ class Dataset(DatasetMeta):
         if storage_type not in {"local", "external"}:
             raise InvalidParamsError(param_name="storage_type", param_value=storage_type)
 
+        self.checkout(self._version)
         export_type = "annotation_uri" if self._annotation_status == 2 else "uri_json_standard"
 
         post_data: Dict[str, Any] = {
@@ -525,7 +526,7 @@ class Dataset(DatasetMeta):
         if not os.path.exists(os.path.dirname(file_name)):
             os.makedirs(os.path.dirname(file_name), 0o0755)
 
-        obj_url = file_name.strip(file_path).strip("/")
+        obj_url = file_name[len(file_path) + 1:]
 
         return key, file_name, obj_url
 
